==> sui-tool-task-manager-1.1.0.tgz: package/lib/domain/task/Entities/factory.js <==
import { SharedValueObjectsFactory } from '../../shared/ValueObjects/factory.js';
import { TaskValueObjectsFactory } from '../ValueObjects/factory.js';
import { TaskEntity } from './TaskEntity.js';
import { WorkTaskEntity } from './WorkTaskEntity.js';
export var TaskEntitiesFactory = function TaskEntitiesFactory() {};
TaskEntitiesFactory.taskEntity = function (_ref) {
  var config = _ref.config,
    id = _ref.id,
    log = _ref.log,
    name = _ref.name,
    priority = _ref.priority,
    work = _ref.work,
    status = _ref.status,
    createdAt = _ref.createdAt,
    _ref$finishedAt = _ref.finishedAt,
    finishedAt = _ref$finishedAt === void 0 ? null : _ref$finishedAt,
    _ref$updatedAt = _ref.updatedAt,
    updatedAt = _ref$updatedAt === void 0 ? null : _ref$updatedAt;
  return new TaskEntity({
    config: config,
    createdAt: SharedValueObjectsFactory.dateSharedValueObject(createdAt),
    finishedAt: SharedValueObjectsFactory.dateSharedValueObject(finishedAt),
    id: SharedValueObjectsFactory.idSharedValueObject(id),
    log: SharedValueObjectsFactory.stringSharedValueObject(log),
    name: SharedValueObjectsFactory.stringSharedValueObject(name),
    priority: TaskValueObjectsFactory.priorityTaskValueObject(config, priority),
    status: TaskValueObjectsFactory.statusTaskValueObject(config, status),
    updatedAt: SharedValueObjectsFactory.dateSharedValueObject(updatedAt),
    work: TaskValueObjectsFactory.workListTaskValueObject(config, work)
  });
};
TaskEntitiesFactory.workTaskEntity = function (_ref2) {
  var config = _ref2.config,
    autoRetry = _ref2.autoRetry,
    createdAt = _ref2.createdAt,
    _ref2$finishedAt = _ref2.finishedAt,
    finishedAt = _ref2$finishedAt === void 0 ? null : _ref2$finishedAt,
    id = _ref2.id,
    log = _ref2.log,
    name = _ref2.name,
    onComplete = _ref2.onComplete,
    onError = _ref2.onError,
    _ref2$parentId = _ref2.parentId,
    parentId = _ref2$parentId === void 0 ? null : _ref2$parentId,
    percentage = _ref2.percentage,
    start = _ref2.start,
    status = _ref2.status,
    _ref2$updatedAt = _ref2.updatedAt,
    updatedAt = _ref2$updatedAt === void 0 ? null : _ref2$updatedAt;
  return new WorkTaskEntity({
    autoRetry: SharedValueObjectsFactory.numberSharedValueObject(autoRetry),
    config: config,
    createdAt: SharedValueObjectsFactory.dateSharedValueObject(createdAt),
    finishedAt: SharedValueObjectsFactory.dateSharedValueObject(finishedAt),
    id: SharedValueObjectsFactory.idSharedValueObject(id),
    log: SharedValueObjectsFactory.stringSharedValueObject(log),
    name: SharedValueObjectsFactory.stringSharedValueObject(name),
    onComplete: SharedValueObjectsFactory.callbackSharedValueObject(onComplete),
    onError: SharedValueObjectsFactory.callbackSharedValueObject(onError),
    parentId: SharedValueObjectsFactory.idSharedValueObject(parentId),
    percentage: SharedValueObjectsFactory.numberSharedValueObject(percentage),
    start: SharedValueObjectsFactory.callbackSharedValueObject(start),
    status: TaskValueObjectsFactory.statusTaskValueObject(config, status),
    updatedAt: SharedValueObjectsFactory.dateSharedValueObject(updatedAt)
  });
};

==> sui-tool-task-manager-1.3.0.tgz: package/lib/domain/task/Entities/factory.js <==
import { SharedValueObjectsFactory } from '../../shared/ValueObjects/factory.js';
import { TaskValueObjectsFactory } from '../ValueObjects/factory.js';
import { TaskEntity } from './TaskEntity.js';
import { WorkTaskEntity } from './WorkTaskEntity.js';
export var TaskEntitiesFactory = function TaskEntitiesFactory() {};
TaskEntitiesFactory.taskEntity = function (_ref) {
  var config = _ref.config,
    id = _ref.id,
    log = _ref.log,
    name = _ref.name,
    priority = _ref.priority,
    work = _ref.work,
    status = _ref.status,
    createdAt = _ref.createdAt,
    _ref$finishedAt = _ref.finishedAt,
    finishedAt = _ref$finishedAt === void 0 ? null : _ref$finishedAt,
    _ref$updatedAt = _ref.updatedAt,
    updatedAt = _ref$updatedAt === void 0 ? null : _ref$updatedAt;
  var taskId = SharedValueObjectsFactory.idSharedValueObject(id);
  return new TaskEntity({
    config: config,
    createdAt: SharedValueObjectsFactory.dateSharedValueObject(createdAt),
    finishedAt: SharedValueObjectsFactory.dateSharedValueObject(finishedAt),
    id: taskId,
    log: SharedValueObjectsFactory.stringSharedValueObject(log),
    name: SharedValueObjectsFactory.stringSharedValueObject(name),
    priority: TaskValueObjectsFactory.priorityTaskValueObject(config, priority),
    status: TaskValueObjectsFactory.statusTaskValueObject(config, status),
    updatedAt: SharedValueObjectsFactory.dateSharedValueObject(updatedAt),
    work: TaskValueObjectsFactory.workListTaskValueObject(config, work, taskId.get())
  });
};
TaskEntitiesFactory.workTaskEntity = function (_ref2) {
  var config = _ref2.config,
    autoRetry = _ref2.autoRetry,
    createdAt = _ref2.createdAt,
    _ref2$finishedAt = _ref2.finishedAt,
    finishedAt = _ref2$finishedAt === void 0 ? null : _ref2$finishedAt,
    id = _ref2.id,
    log = _ref2.log,
    name = _ref2.name,
    onComplete = _ref2.onComplete,
    onError = _ref2.onError,
    _ref2$parentId = _ref2.parentId,
    parentId = _ref2$parentId === void 0 ? null : _ref2$parentId,
    percentage = _ref2.percentage,
    start = _ref2.start,
    status = _ref2.status,
    _ref2$taskId = _ref2.taskId,
    taskId = _ref2$taskId === void 0 ? null : _ref2$taskId,
    _ref2$updatedAt = _ref2.updatedAt,
    updatedAt = _ref2$updatedAt === void 0 ? null : _ref2$updatedAt;
  return new WorkTaskEntity({
    autoRetry: SharedValueObjectsFactory.numberSharedValueObject(autoRetry),
    config: config,
    createdAt: SharedValueObjectsFactory.dateSharedValueObject(createdAt),
    finishedAt: SharedValueObjectsFactory.dateSharedValueObject(finishedAt),
    id: SharedValueObjectsFactory.idSharedValueObject(id),
    log: SharedValueObjectsFactory.stringSharedValueObject(log),
    name: SharedValueObjectsFactory.stringSharedValueObject(name),
    onComplete: SharedValueObjectsFactory.callbackSharedValueObject(onComplete),
    onError: SharedValueObjectsFactory.callbackSharedValueObject(onError),
    parentId: SharedValueObjectsFactory.idSharedValueObject(parentId),
    percentage: SharedValueObjectsFactory.numberSharedValueObject(percentage),
    start: SharedValueObjectsFactory.callbackSharedValueObject(start),
    status: TaskValueObjectsFactory.statusTaskValueObject(config, status),
    taskId: SharedValueObjectsFactory.idSharedValueObject(taskId),
    updatedAt: SharedValueObjectsFactory.dateSharedValueObject(updatedAt)
  });
};
